@@ -1,3 +1,9 @@
+use super::dynamic_returnable::DynamicReturnable;
+use super::evaluation_types::ExtraExposureInfo;
+use super::evaluation_types_v2::{
+    BaseEvaluationV2, DynamicConfigEvaluationV2, ExperimentEvaluationV2, GateEvaluationV2,
+    LayerEvaluationV2,
+};
 use crate::evaluation::evaluation_types::{
     BaseEvaluation, DynamicConfigEvaluation, ExperimentEvaluation, GateEvaluation, LayerEvaluation,
     SecondaryExposure,
@@ -5,15 +11,6 @@ use crate::evaluation::evaluation_types::{
 use crate::event_logging::exposable_string::{self, ExposableString};
 use crate::hashing::{HashAlgorithm, HashUtil};
 use crate::specs_response::spec_types::Spec;
-use serde_json::Value;
-use std::collections::HashMap;
-use std::sync::Arc;
-
-use super::evaluation_types::ExtraExposureInfo;
-use super::evaluation_types_v2::{
-    BaseEvaluationV2, DynamicConfigEvaluationV2, ExperimentEvaluationV2, GateEvaluationV2,
-    LayerEvaluationV2,
-};
 
 #[derive(Default, Debug)]
 pub struct EvaluatorResult<'a> {
@@ -25,7 +22,7 @@ pub struct EvaluatorResult<'a> {
     pub is_in_layer: bool,
     pub is_in_experiment: bool,
     pub id_type: Option<&'a String>,
-    pub json_value: Option<HashMap<String, Value>>,
+    pub json_value: Option<DynamicReturnable>,
     pub rule_id: Option<&'a ExposableString>,
     pub rule_id_suffix: Option<&'static str>,
     pub group_name: Option<&'a String>,
@@ -271,8 +268,11 @@ fn get_id_type_info(id_type: Option<&String>) -> (String, bool) {
     (id_type, is_device_based)
 }
 
-fn get_json_value(result: &EvaluatorResult) -> HashMap<String, Value> {
-    result.json_value.clone().unwrap_or_default()
+fn get_json_value(result: &mut EvaluatorResult) -> DynamicReturnable {
+    result
+        .json_value
+        .take()
+        .unwrap_or_else(DynamicReturnable::empty)
 }
 
 // todo: remove when 'QueuedExposure' does not use `BaseEvaluation`
@@ -284,7 +284,7 @@ fn get_exposure_name_if_not_hashed(
     if possibly_hashed_name == exposure_name.as_str() {
         exposure_name.clone()
     } else {
-        ExposableString::new(possibly_hashed_name.to_string())
+        ExposableString::from_str_ref(possibly_hashed_name)
     }
 }
 
@@ -341,12 +341,12 @@ fn create_suffixed_rule_id(
     suffix: Option<&str>,
 ) -> ExposableString {
     let id_arc = match &rule_id {
-        Some(rule_id) => rule_id.clone_inner(),
-        None => Arc::new(String::new()),
+        Some(rule_id) => rule_id.as_str(),
+        None => "",
     };
 
     match &suffix {
-        Some(suffix) => ExposableString::new(format!("{id_arc}:{suffix}")),
+        Some(suffix) => ExposableString::from_str_parts(&[id_arc, ":", suffix]),
         None => rule_id.cloned().unwrap_or_default(),
     }
 }
