@@ -18,6 +18,7 @@ pub struct EnqueueExperimentExpoOp<'a> {
     pub user: &'a StatsigUserInternal<'a, 'a>,
     pub experiment: &'a Experiment,
     pub trigger: ExposureTrigger,
+    pub exposure_time: u64,
 }
 
 impl EnqueueOperation for EnqueueExperimentExpoOp<'_> {
@@ -43,6 +44,7 @@ impl EnqueueOperation for EnqueueExperimentExpoOp<'_> {
             exposure_trigger: self.trigger,
             sampling_decision,
             override_config_name,
+            exposure_time: self.exposure_time,
         })
     }
 }
@@ -85,6 +87,7 @@ pub struct QueuedExperimentExposureEvent {
     pub exposure_trigger: ExposureTrigger,
     pub sampling_decision: EvtSamplingDecision,
     pub override_config_name: Option<String>,
+    pub exposure_time: u64,
 }
 
 impl QueuedExperimentExposureEvent {
@@ -115,6 +118,7 @@ impl QueuedExperimentExposureEvent {
         };
 
         StatsigEventInternal::new(
+            self.exposure_time,
             self.user,
             event,
             Some(self.secondary_exposures.unwrap_or_default()),
