@@ -71,6 +71,10 @@ impl StatsigHttpIdListsAdapter {
         }
     }
 
+    pub fn force_shutdown(&self) {
+        self.shutdown_notify.notify_one();
+    }
+
     async fn fetch_id_list_manifests_from_network(&self) -> Result<IdListsResponse, StatsigErr> {
         let request_args = RequestArgs {
             url: self.id_lists_manifest_url.clone(),
@@ -208,8 +212,7 @@ impl StatsigHttpIdListsAdapter {
                     self.ops_stats.clone(),
                     TAG,
                     StatsigErr::LockFailure(format!(
-                        "Failed to acquire write lock on listener: {}",
-                        e
+                        "Failed to acquire write lock on listener: {e}"
                     ))
                 );
             }
@@ -383,7 +386,7 @@ impl IdListsAdapter for StatsigHttpIdListsAdapter {
 }
 
 fn make_default_cdn_url(sdk_key: &str) -> String {
-    format!("{}/{}.json", DEFAULT_CDN_ID_LISTS_MANIFEST_URL, sdk_key)
+    format!("{DEFAULT_CDN_ID_LISTS_MANIFEST_URL}/{sdk_key}.json")
 }
 
 #[cfg(test)]
